@@ -180,11 +180,11 @@ def validate_grading(ctx, param, value):
         return value
     if value is None:
         return value
-    match = re.match('^[+\\-~0]*$', value)
+    match = re.match('^((\\d*\\.\\d+|\\d+\\.?)/)*(\\d*\\.\\d+|\\d+\\.?)$', value)
     if match is not None:
         return value
     else:
-        raise click.BadParameter('can only consist of [\'+\', \'~\', \'-\', \'0\']')
+        raise click.BadParameter('can only consist of a slash separated list of numbers')
 
 
 def validate_ex_type(ctx, param, value):
@@ -218,10 +218,9 @@ def validate_ex_type_ta(ctx, param, value):
 @click.option("--solution-remarks", prompt=True, default='', help='remarks for the lecturer (keep short)')
 @click.option("--grading", callback=validate_grading, prompt=False, required=False,
               help='grade for the submission')
-@click.option('--tasks', type=int, help='number of tasks for this exercise', default=-1)
-@click.option('--points', type=click.IntRange(0, 33), help='points for team exercise', callback=validate_ex_type_ta)
+@click.option('--points', type=click.INT, help='points for team exercise', callback=validate_ex_type_ta)
 @click.pass_context
-def grade(ctx, group, ue: int, student, grading, student_feedback, solution_remarks, tasks, points):
+def grade(ctx, group, ue: int, student, grading, student_feedback, solution_remarks, points):
     ep2 = Ep2(verbose=ctx.obj["VERBOSE"], sudo=ctx.obj["SUDO"])
     group = ep2.group(group)
     f_info = FileInformation('Grade')
@@ -238,12 +237,18 @@ def grade(ctx, group, ue: int, student, grading, student_feedback, solution_rema
     elif curr_ue_type == ExerciseType.Normal:
         if grading is None:
             grading = click.prompt('Grading')
-            while not re.match('^[+\\-~0]*$', grading):
+            while not re.match('^((\\d*\\.\\d+|\\d+\\.?)/)*(\\d*\\.\\d+|\\d+\\.?)$', grading):
                 grading = click.prompt('Grading')
     else:
         click.secho('Unknown exercise type %s' % curr_ue_type, fg='red')
         exit(1)
 
+    grading_correct, grading = ep2.validate_grading(ue, grading)
+
+    if not grading_correct:
+        click.secho('Some gradings are above the maximum point value')
+        exit(2)
+
     try:
         team_index = TeamIndex(group)
     except:
@@ -291,7 +296,7 @@ def grade(ctx, group, ue: int, student, grading, student_feedback, solution_rema
                 if curr_ue_type == ExerciseType.Normal:
                     student_id = row[KEY_STUDENT_ID]
                     if student_id == student:
-                        row[KEY_UE_GRADING] = grading
+                        row[KEY_UE_GRADING] = "/".join([str(grade) for grade in grading])
 
                         if solution_remarks is not None:
                             row[KEY_UE_REMARKS] = escape_csv_string(solution_remarks)
@@ -376,6 +381,7 @@ def submit(ctx, group: str, ue: int):
 
     template = Template(file=ep2.template_path('pre_eval.tmpl'))
     template.tutor_gender = ep2.tutor_gender()
+    template.subtasks = ep2.get_exercise_subtasks(ue)
 
     with open(exercise_csv_file, 'r') as infile:
         reader = csv.DictReader(infile, fnames, KEY_INVALID, strict=True)
@@ -413,9 +419,21 @@ def submit(ctx, group: str, ue: int):
                         exit(1)
                         return
 
+                    grading_correct, grading = ep2.validate_grading(ue, grading)
+
+                    if not grading_correct:
+                        click.secho('the grading for student {} is not correct. (either wrong number of subgrades or '
+                                    'subgrade > max_points for subgrade)'.format(row[KEY_STUDENT_ID]))
+
                     template.grading = grading
+                    if len(template.grading) < len(template.subtasks):
+                        template.grading += [float(0)] * (len(template.subtasks) - len(template.grading))
+
                     template.tests = [row[KEY_UE_PRE_EVAL_EX % d] for d in range(1, ep2.tests_for_exercise(ue) + 1)]
                     template.points = -1
+
+                    row[KEY_UE_GRADING] = "/".join([str(grade) for grade in grading])
+
                 elif curr_ue_type == ExerciseType.Team:
                     points = row[KEY_UE_TA_POINTS]
                     if points == '_':
@@ -531,7 +549,7 @@ def list_ungraded(ctx, ue, group):
         exit(1)
 
     if empty:  # all work is done!
-        click.secho('empty', fg='green')
+        click.secho('all graded!', fg='green', bold=True)
 
 
 if __name__ == '__main__':
