@@ -1,5 +1,7 @@
 #!/usr/bin/env python3
 # coding=utf-8
+from gitlab.exceptions import GitlabAuthenticationError
+
 from ep2_core.common import *
 
 
@@ -16,7 +18,7 @@ def util_grp(ctx, verbose):
 
 
 @util_grp.command('init')
-@click.option('--semester', type=click.Choice(['2019s', '2020s']), help='automatically provides values for gitlab-repo-prefix '
+@click.option('--semester', type=click.Choice(['2019s', '2020s', '2021s']), help='automatically provides values for gitlab-repo-prefix '
                                                                'and gitlab-url',
               required=False)
 @click.option('--git-home', prompt=True, required=True, help='directory in which the repositories will be stored '
@@ -30,7 +32,8 @@ def util_grp(ctx, verbose):
 @click.option("--gender", prompt=True, required=True, help='the gender you identify with, used for greeting lines in '
                                                            'issues', type=click.Choice(['male', 'female', 'diverse']))
 @click.option('--idea-eval-dir', prompt=True, help='directory to copy projects to, so idea will display them correctly')
-def util_init(semester, git_home, gitlab_url, gitlab_repo_prefix, gitlab_access_token, idea_eval_dir, gender):
+@click.option('--tutor-repo', required=False, help='path to the tutor repo if it is already cloned')
+def util_init(semester, git_home, gitlab_url, gitlab_repo_prefix, gitlab_access_token, idea_eval_dir, gender, tutor_repo):
     """This command generates a config file that contains all necessary information to connect to the Gitlab instance
     and grade the ad-hoc exercises.
 
@@ -67,6 +70,8 @@ def util_init(semester, git_home, gitlab_url, gitlab_repo_prefix, gitlab_access_
     config.set('Local', 'GitHome', os.path.expanduser(git_home))
     if idea_eval_dir is not None and idea_eval_dir != '':
         config.set('Local', 'IdeaEvalDir', os.path.expanduser(idea_eval_dir))
+    if tutor_repo is not None:
+        config.set('Local', 'TutorRepo', os.path.abspath(tutor_repo))
 
     if semester is not None:  # Use default settings for a specific semester
         if semester == '2019s':  # Semester 2019S
@@ -75,6 +80,9 @@ def util_init(semester, git_home, gitlab_url, gitlab_repo_prefix, gitlab_access_
         if semester == '2020s':  # Semester 2020s
             config.set('Gitlab', 'URL', 'https://b3.complang.tuwien.ac.at/')
             config.set('Gitlab', 'RepoPrefix', 'ep2/2020s')
+        if semester == '2021s':
+            config.set('Gitlab', 'URL', 'https://b3.complang.tuwien.ac.at/')
+            config.set('Gitlab', 'RepoPrefix', 'ep2/2021s')
         else:  # Should not be possible
             click.secho('unimplemented semester: ' + semester, fg='red')
             exit(1)
@@ -107,12 +115,15 @@ def util_test():
     command will output 'ok'"""
     ep2 = Ep2()
 
-    ep2.gitlab.auth()
-    if ep2.gitlab.user is not None:
-        click.secho('ok', fg='green')
-    else:
-        click.secho('fail', fg='red')
-
+    try:
+        ep2.gitlab.auth()
+        if ep2.gitlab.user is not None:
+            click.secho('ok', fg='green', bold=True)
+        else:
+            click.secho('fail', fg='red', bold=True)
+    except GitlabAuthenticationError:
+        click.secho('fail', fg='red', bold=True)
+        click.secho('Authentication error')
 
 @util_grp.command('tag')
 @click.option("--group", required=True, prompt=True, help='name of the group')
